.. _lionagi-core-operations:

=======================
Core Operation Modules
=======================

Below you find references for high-level functions such as:

- `brainstorm` (multi-turn idea generation)
- `plan` (multi-step plan creation and optional execution)
- plus any additional top-level calls in `lionagi.operations`

.. currentmodule:: lionagi.operations

Brainstorm
----------
.. autofunction:: brainstorm
   :noindex:

Plan
----------
.. autofunction:: plan
   :noindex:
